numina.modeling — Model for fitting — Numina 0.20.dev0 documentation

# `numina.modeling` — Model for fitting

class `numina.modeling.enclosed.` `EnclosedGaussian`(amplitude, stddev, **kwargs)

  Enclosed Gaussian model

class `numina.modeling.gaussbox.` `GaussBox`(amplitude=1.0, mean=0.0, stddev=1.0, hpix=0.5, **kwargs)

  Model for fitting a 1D Gaussina convolved with a square

`numina.modeling.gaussbox.` `gauss_box_model`(x, amplitude=1.0, mean=0.0, stddev=1.0, hpix=0.5)

  Integrate a Gaussian profile.

`numina.modeling.gaussbox.` `gauss_box_model_deriv`(x, amplitude=1.0, mean=0.0, stddev=1.0, hpix=0.5)

  Derivative of the integral of a Gaussian profile.

`numina.modeling.sumofgauss.` `sum_of_gaussian_factory`(N)

  Return a model of the sum of N Gaussians and a constant background.